Learn R Programming

fbroc (version 0.3.0)

conf.fbroc.roc: Generates confidence intervals for the TPR for a range of FPRs or vice versa

Description

Calculates confidence intervals for the TPR at different FPR values or vice versa. The stepsize at which the TPR or FPR is calculated can be set as needed.

Usage

## S3 method for class 'fbroc.roc':
conf(roc, conf.level = 0.95, conf.for = "tpr",
  steps = 250, ...)

Arguments

roc
Object of class fbroc.roc.
conf.level
Confidence level to be used for the confidence intervals. Defaults to 0.95.
conf.for
Use "tpr" to get confidence regions for the TPR at specific FPRs. Use "fpr" instead for confidence regions for the FPR at specific TPRs.
steps
Number of discrete steps at which the requested rate and the confidence region is calculated. Defaults to 250.
...
Further arguments, that are not used at this time.

Value

  • A data.frame containing either discrete TPR steps and estimates and confidence bounds for FPR or vice versa, depending upon conf.for.

See Also

boot.roc

Examples

Run this code
data(roc.examples)
example <- boot.roc(roc.examples$Cont.Pred, roc.examples$True.Class,
                    n.boot = 100)
conf(example, conf.for = "tpr", steps = 10) # get confidence regions for TPR at FPR
conf(example, conf.for = "fpr", steps = 10) # get confidence regions for FPR at TPR

Run the code above in your browser using DataLab