fbroc-package: fbroc: Fast Algorithms to Bootstrap Receiver Operating...

fbroc-packageR Documentation

fbroc: Fast Algorithms to Bootstrap Receiver Operating Characteristics Curves

Description

Implements a very fast C++ algorithm to quickly bootstrap receiver operating characteristics (ROC) curves and derived performance metrics, including the area under the curve (AUC) and the partial area under the curve as well as the true and false positive rate. The analysis of paired receiver operating curves is supported as well, so that a comparison of two predictors is possible. You can also plot the results and calculate confidence intervals. On a typical desktop computer the time needed for the calculation of 100000 bootstrap replicates given 500 observations requires time on the order of magnitude of one second.

Author(s)

Maintainer: Erik Peter jerikpeter@googlemail.com

Authors:

See Also

Useful links:


fbroc documentation built on Sept. 6, 2026, 5:07 p.m.