Learn R Programming

fbroc (version 0.3.1)

perf.fbroc.paired.roc: Calculate performance for paired bootstrapped ROC curves

Description

For a given metric this calculates the difference in performance between two paired predictors stored in an object of class fbroc.paired.roc in addition to their individual performance.

Usage

## S3 method for class 'fbroc.paired.roc':
perf(roc, metric = "auc", conf.level = 0.95,
  tpr = NULL, fpr = NULL, ...)

Arguments

roc
An object of class fbroc.paired.roc.
metric
A performance metric. Select "auc" for the AUC, "tpr" for the TPR at a fixed FPR and "fpr" for the FPR at a fixed TPR.
conf.level
The confidence level of the confidence interval.
tpr
The fixed TPR at which the FPR is to be evaluated when fpr is selected as metric.
fpr
The fixed FPR at which the TPR is to be evaluated when tpr is selected as metric.
...
Further arguments, that are not used at this time.

Examples

Run this code
data(roc.examples)
example <- boot.paired.roc(roc.examples$Cont.Pred, roc.examples$Cont.Pred.Outlier,
                               roc.examples$True.Class)
perf(example, metric = "auc")
perf(example, metric = "tpr", fpr = 0.2) # Get difference in TPR at a FPR of 20\%

Run the code above in your browser using DataLab