View source: R/fbroc.methods.R
| plot.fbroc.perf | R Documentation |
Given an object of class fbroc.perf this function plots the results of
the bootstrap as a histogram. The confidence interval is also included by
default.
## S3 method for class 'fbroc.perf'
plot(
x,
bins = NULL,
col = "white",
fill = "lightblue",
print.plot = TRUE,
show.conf = TRUE,
conf.text = TRUE,
...
)
x |
Object of class |
bins |
Number of bins for histogram. Default value depends on the number of bootstrap values and the number of unique bootstrap performance values. |
col |
Color of outline of histogram bars. Defaults to white. |
fill |
Fill of histogram bars. Defaults to lightblue. |
print.plot |
Logical specifying whether the plot should be printed. |
show.conf |
Logical specifying whether the confidence interval should be displayed. |
conf.text |
Logical specifying whether the confidence interval limits should also be displayed as text. |
... |
Further arguments passed to or from other methods. |
A ggplot, so that the user can customize the plot further.
perf.fbroc.roc
y <- rep(c(TRUE, FALSE), each = 500)
x <- rnorm(1000) + y
result.boot <- boot.roc(x, y, n.boot = 1000)
result.perf <- perf(result.boot, "auc")
plot(result.perf)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.