View source: R/fbroc.paired.methods.R
| plot.fbroc.perf.paired | R Documentation |
Given an object of class fbroc.perf.paired this function plots the difference between the
bootstrapped performance estimate of the first and the second classifier as a histogram.
the bootstrap as an histogram. The confidence interval is also shown by
default.
## S3 method for class 'fbroc.perf.paired'
plot(
x,
bins = NULL,
col = "white",
fill = "lightblue",
print.plot = TRUE,
show.conf = TRUE,
conf.text = TRUE,
...
)
x |
An object of class |
bins |
Number of bins for histogram. Default value depends on the number of bootstrap values and the number of unique bootstrap performance values. |
col |
Color of outline of histogram bars. Defaults to white. |
fill |
Fill of histogram bars. Defaults to lightblue. |
print.plot |
Logical specifying whether the plot should be printed. |
show.conf |
Logical specifying whether the confidence interval should be displayed. |
conf.text |
Logical specifying whether the confidence interval limits should also be displayed as text. |
... |
Further arguments passed to or from other methods. |
A ggplot, so that the user can customize the plot further.
perf.fbroc.paired.roc
data(roc.examples)
example <- boot.paired.roc(roc.examples$Cont.Pred, roc.examples$Cont.Pred.Outlier,
roc.examples$True.Class, n.boot = 100)
auc.diff <- perf(example, "auc")
plot(auc.diff)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.