View source: R/fbroc.methods.R
| print.fbroc.perf | R Documentation |
fbroc.perf objectPrints the information about the bootstrap results for an object of class
fbroc.perf. This information includes the number of bootstrap
replicates, the metric used and the estimate with confidence interval.
## S3 method for class 'fbroc.perf'
print(x, ...)
x |
Object of class |
... |
further arguments passed to or from other methods. |
Character containing the text that is also printed.
perf.fbroc.roc
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.