View source: R/fbroc.paired.methods.R
| print.fbroc.perf.paired | R Documentation |
fbroc.perf.paired objectPrints the information about the bootstrap results for an object of class
fbroc.perf.paired. This information includes the number of bootstrap
replicates, the metric used and estimates for both the individual classifiers and the
difference in performance including confidence intervals. Finally, an estimate for the
correlation between the performance estimates of the two classifiers is also given.
## S3 method for class 'fbroc.perf.paired'
print(x, ...)
x |
Object of class |
... |
further arguments passed to or from other methods. |
Character containing the text that is also printed.
perf.fbroc.paired.roc
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.