roc.examples: Examples of predictions for ROC curve construction

roc.examplesR Documentation

Examples of predictions for ROC curve construction

Description

Contains simulated data that can be used as examples for generating ROC curves. Both a continuous and a discrete predictor are included. For both cases there is a version with outliers and one without.

Usage

roc.examples

Format

A data.frame with 160 rows and 5 variables:

True.Class

True class label of the observation

Cont.Pred

Predictions for which the binormal model for ROC curves holds. Predictions for both the positive and negative class follows a normal distribution with unit standard deviation and means 2 and 0 respectively.

Cont.Pred.Outlier

Same as above, with some extreme outliers in the negative class.

Disc.Pred

Example of a discrete predictor. Predictions for the negative class are integer values between 1 and 8, positive samples have integer predictions between 7 and 14.

Disc.Pred.Outlier

Same as above, with some extreme outliers in the negative class.


fbroc documentation built on Sept. 6, 2026, 5:07 p.m.