Learn R Programming

fbroc (version 0.5.0)

plot.fbroc.perf: Plots ROC based performance metric as histogram

Description

Given an object of class fbroc.perf this function plots the results of the bootstrap as a histogram. The confidence interval is also included by default.

Usage

# S3 method for fbroc.perf
plot(
  x,
  bins = NULL,
  col = "white",
  fill = "lightblue",
  print.plot = TRUE,
  show.conf = TRUE,
  conf.text = TRUE,
  ...
)

Value

A ggplot, so that the user can customize the plot further.

Arguments

x

Object of class fbroc.perf to be plotted.

bins

Number of bins for histogram. Default value depends on the number of bootstrap values and the number of unique bootstrap performance values.

col

Color of outline of histogram bars. Defaults to white.

fill

Fill of histogram bars. Defaults to lightblue.

print.plot

Logical specifying whether the plot should be printed.

show.conf

Logical specifying whether the confidence interval should be displayed.

conf.text

Logical specifying whether the confidence interval limits should also be displayed as text.

...

Further arguments passed to or from other methods.

See Also

perf.fbroc.roc

Examples

Run this code
y <- rep(c(TRUE, FALSE), each = 500)
x <- rnorm(1000) + y
result.boot <- boot.roc(x, y, n.boot = 1000)
result.perf <- perf(result.boot, "auc")
plot(result.perf)

Run the code above in your browser using DataLab