Learn R Programming

fbroc (version 0.5.0)

print.fbroc.perf: Prints information about a fbroc.perf object

Description

Prints the information about the bootstrap results for an object of class fbroc.perf. This information includes the number of bootstrap replicates, the metric used and the estimate with confidence interval.

Usage

# S3 method for fbroc.perf
print(x, ...)

Value

Character containing the text that is also printed.

Arguments

x

Object of class fbroc.perf.

...

further arguments passed to or from other methods.

See Also

perf.fbroc.roc