fbroc.perf.paired objectfbroc.perf.paired. This information includes the number of bootstrap
replicates, the metric used and estimates for both the individual classifiers and the
difference in performance including confidence intervals. Finally, an estimate for the
correlation between the performance estimates of the two classifiers is also given.## S3 method for class 'fbroc.perf.paired':
print(x, ...)fbroc.perf.perf.fbroc.paired.roc